tmp<fv::convectionScheme<scalar> > mvConvection1
(
    fv::convectionScheme<scalar>::New
    (
        mesh,
        fields1,
        phi,
        mesh.divScheme("div(phi,Yi_h)")
    )
);

tmp<fv::convectionScheme<scalar> > mvConvection2
(
    fv::convectionScheme<scalar>::New
    (
        mesh,
        fields2,
        phi,
        mesh.divScheme("div(phi,Yi_h)")
    )
);

mixture.reactionCorrect();
dQ = mixture.dQ();

{
    label inertIndex = -1;
    volScalarField Y1t(0.0*Y1[0]);

    forAll(Y1, i)
    {
        bool activeSpecie = false;
        label activeSpecieIndex = -1;

        forAll(massTransferActivceSpecies, j)
        {
            if(Y1[i].name() ==  massTransferActivceSpecies[j]+"."+mixture.phase1Name())
            {
                activeSpecie = true;
                activeSpecieIndex = j;
            }
        }

        if (Y1[i].name() != inertSpecie1)
        {  
            volScalarField effDiff = mixture.effDiffusivity
            (
                Y1[i],
                rho1, 
                turbulence->mut(),
                mixture.phase1Name()
            );

            volScalarField alpha(max(alpha1, VSMALL));
            volScalarField& Y1i = Y1[i];
            surfaceScalarField alphaRhoPhi = fvc::interpolate(alpha) * fvc::interpolate(rho1)*phi;
            surfaceScalarField alphaDiffEff = fvc::interpolate(alpha) * fvc::interpolate(effDiff);

            fvScalarMatrix Y1iEqn
            (
                fvm::ddt(alpha, rho1, Y1i)
              + mvConvection1->fvmDiv(alphaRhoPhi, Y1i)
              - fvm::Sp(fvc::ddt(alpha, rho1) + fvc::div(alphaRhoPhi), Y1i)
              - fvm::laplacian(alphaDiffEff, Y1i)
             ==
                alpha * mixture.reaction1()->R(Y1i)
            );

            Y1iEqn.relax();

            if (activeSpecie)
            {   
                solve
                (
                    Y1iEqn == alpha * speciesmDots[activeSpecieIndex], 
                    mesh.solver("Y1i")
                );
            }
            else
            {
                solve
                (
                    Y1iEqn,
                    mesh.solver("Y1i")
                );                                          
            }

            Y1i.max(0.0);

            Y1t += Y1i;
        }
        else
        {
            inertIndex = i;
        }
    }

    Y1[inertIndex] = scalar(1) - Y1t;
    Y1[inertIndex].max(0.0);
}

{
    label inertIndex = -1;
    volScalarField Y2t(0.0*Y2[0]);

    forAll(Y2, i)
    {
        bool activeSpecie = false;
        label activeSpecieIndex = -1;

        forAll(massTransferActivceSpecies, j)
        {
            if(Y2[i].name() ==  massTransferActivceSpecies[j]+"."+mixture.phase2Name())
            {
                activeSpecie = true;
                activeSpecieIndex = j;
            }
        }

        if (Y2[i].name() != inertSpecie2)
        {
            volScalarField effDiff = mixture.effDiffusivity
            (
                Y2[i], 
                rho2,
                turbulence->mut(),
                mixture.phase2Name()
            );
        
            volScalarField alpha(max(alpha2, VSMALL));
            volScalarField& Y2i = Y2[i];
            surfaceScalarField alphaRhoPhi = fvc::interpolate(alpha) * fvc::interpolate(rho2)*phi;
            surfaceScalarField alphaDiffEff = fvc::interpolate(alpha) * fvc::interpolate(effDiff);

            fvScalarMatrix Y2iEqn
            (
                fvm::ddt(alpha, rho2, Y2i)
              + mvConvection2->fvmDiv(alphaRhoPhi, Y2i)
              - fvm::Sp(fvc::ddt(alpha, rho2) + fvc::div(alphaRhoPhi), Y2i)
              - fvm::laplacian(alphaDiffEff, Y2i)
             ==
                alpha * mixture.reaction2()->R(Y2i)
            );

            Y2iEqn.relax();

            if (activeSpecie)
            {   
                solve
                (
                    Y2iEqn == -alpha * speciesmDots[activeSpecieIndex], 
                    mesh.solver("Y2i")
                );
            }
            else
            {
                solve
                (
                    Y2iEqn,
                    mesh.solver("Y2i")
                );                                          
            }

            Y2i.max(0.0);

            Y2t += Y2i;
        }
        else
        {
            inertIndex = i;
        }
    }

    Y2[inertIndex] = scalar(1) - Y2t;
    Y2[inertIndex].max(0.0);
}