/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::Henrys::constant

Description
    The molar fraction henry's constant is read from dictionary (as a 
    constant)and corrected based on the defined direction in the dictionary 
    and returned as a volScalarField type

SourceFiles
    constant.C

\*---------------------------------------------------------------------------*/

#ifndef constant_H
#define constant_H

#include "Henry.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace Henrys
{

/*---------------------------------------------------------------------------*\
                           Class constant Declaration
\*---------------------------------------------------------------------------*/

class constant
:
    public Henry
{

protected:

    const dictionary& dict_;
    const word& specie_;

    
public:

    //- Runtime type information
    TypeName("constant");

    // Constructors

        //- Construct from components
        constant
        (
            const fvMesh& mesh,
            const dictionary& dict,
            const volVectorField& U,
            const word& specieName = equilibriumModel::typeName,
            const word& modelName = typeName
        );


    //- Destructor
    virtual ~constant()
    {}


    // Member Functions

        virtual tmp<volScalarField> henryCoeff();

        //- Correct mass transfer model
        virtual void correctEquilibrium();

        //- Read dictionary
        virtual bool read();
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Henrys
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
