/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::interfaceAreaModels::gradAlpha

Description
    Interface surface area is calculated based on the grad(alpha) per
    unit volume and returned as a volScalarField

SourceFiles
    gradAlpha.C

\*---------------------------------------------------------------------------*/

#ifndef gradAlpha_H
#define gradAlpha_H

#include "interfaceAreaModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace interfaceAreaModels
{

/*---------------------------------------------------------------------------*\
                           Class gradAlpha Declaration
\*---------------------------------------------------------------------------*/

class gradAlpha
:
    public interfaceAreaModel
{

protected:

    const fvMesh& mesh_;
    const dictionary& dict_;

    
public:

    //- Runtime type information
    TypeName("gradAlpha");

    // Constructors

        //- Construct from components
        gradAlpha
        (
            const fvMesh& mesh,
            const dictionary& dict,
            const word& modelName = typeName
        );


    //- Destructor
    virtual ~gradAlpha()
    {}


    // Member Functions

        //- Return the specific interface area (m2/m3)  
        virtual tmp<volScalarField> interfaceArea
        (
            const volScalarField& alpha
        );

        //- Read dictionary
        virtual bool read();
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace interfaceAreaModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
