/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Namespace
    Foam::interfaceAreaModels

Group
    grpIcoRASTurbulence

Description
    Namespace for calculating multiphase interface area per cell, subgrid 
    mass-transfer area should be added here

Class
    Foam::interfaceAreaModel

SourceFiles
    interfaceAreaModel.C

\*---------------------------------------------------------------------------*/

#ifndef interfaceAreaModel_H
#define interfaceAreaModel_H

#include "IOdictionary.H"
#include "typeInfo.H"
#include "volFields.H"
#include "dimensionedScalar.H"
#include "Pair.H"
#include "nearWallDist.H"
#include "autoPtr.H"
#include "runTimeSelectionTables.H"
#include "fvCFD.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                           Class interfaceAreaModel Declaration
\*---------------------------------------------------------------------------*/

class interfaceAreaModel
{

protected:

    // Protected data


private:

    // Private Member Functions

        //- Disallow default bitwise copy construct
        interfaceAreaModel(const interfaceAreaModel&);

        //- Disallow default bitwise assignment
        void operator=(const interfaceAreaModel&);


public:

    //- Runtime type information
    TypeName("interfaceAreaModel");


    // Declare run-time constructor selection table

        declareRunTimeSelectionTable
        (
            autoPtr,
            interfaceAreaModel,
            subModel,
            (
                const fvMesh& mesh,
                const dictionary& dict
            ),
            (mesh, dict)
        );


    // Constructors

        //- Construct from components
        interfaceAreaModel
        (
            const word& type,
            const fvMesh& mesh,
            const dictionary& dict
        );


    // Selectors

        //- Return a reference to the selected RAS model
        static autoPtr<interfaceAreaModel> New
        (
            const fvMesh& mesh,
            const dictionary& dict
        );


    //- Destructor
    virtual ~interfaceAreaModel()
    {}


    // Member Functions

        //- Return the specific mass transfer area 
        virtual tmp<volScalarField> interfaceArea(const volScalarField& alpha) = 0;

        //- Read dictionary
        virtual bool read();
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
