/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2013 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "constant.H"
#include "addToRunTimeSelectionTable.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace kineticModels
{

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

defineTypeNameAndDebug(constant, 0);
addToRunTimeSelectionTable(kineticModel, constant, subModel);

// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

constant::constant
(
    const fvMesh& mesh,
    const dictionary& dict,
    const word& specieName,
    const word& modelName
)
:
    kineticModel(modelName, mesh, dict, specieName),
    mesh_(mesh),
    dict_(dict),
    specie_(specieName)
{}


// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //

tmp<volScalarField> constant::massTransferCoeff()
{
    scalar value_ 
        = 
        readScalar(dict_.subDict("interfaceMassTransfer")
        .subDict(specie_)
        .subDict("constantKinetic")
        .lookup("value"));

    tmp<volScalarField> massTransferCoeff_
    (
        new volScalarField
        (
            IOobject
            (
                "massTransferCoeff",
                mesh_.time().timeName(),
                mesh_
            ),
            mesh_,
            dimensionedScalar("massTransferCoeff", dimensionSet(0,1,-1,0,0,0,0), 1.0)
        )
    );

    return value_*massTransferCoeff_;
}


bool constant::read()
{
    return true;
}

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace kineticModels
} // End namespace Foam

// ************************************************************************* //
