/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "kineticModel.H"
#include "addToRunTimeSelectionTable.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

defineTypeNameAndDebug(kineticModel, 0);
defineRunTimeSelectionTable(kineticModel, subModel);

// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

kineticModel::kineticModel
(
    const word& type,
    const fvMesh& mesh,
    const dictionary& dict,
    const word& specieName
)
{}


// * * * * * * * * * * * * * * * * * Selectors * * * * * * * * * * * * * * * //

autoPtr<kineticModel> kineticModel::New
(
    const fvMesh& mesh,
    const dictionary& dict,
    const word& specieName
)
{
    // get model name, but do not register the dictionary
    // otherwise it is registered in the database twice
    const word modelType
    (
        IOdictionary
        (
            IOobject
            (
                "thermophysicalProperties",
                mesh.time().constant(),
                mesh,
                IOobject::MUST_READ_IF_MODIFIED,
                IOobject::NO_WRITE,
                false
            )
        )
        .subDict("interfaceMassTransfer")
        .subDict(specieName)
        .lookup("kineticModel")
    );

    Info<< "Selecting mass transfer coefficient model " << modelType << nl << endl;

    subModelConstructorTable::iterator cstrIter =
        subModelConstructorTablePtr_->find(modelType);

    if (cstrIter == subModelConstructorTablePtr_->end())
    {
        FatalErrorInFunction
            << "Unknown mass transfer coefficient type "
            << modelType << nl << nl
            << "Valid mass transfer coefficient types:" << endl
            << subModelConstructorTablePtr_->sortedToc()
            << exit(FatalError);
    }

    return autoPtr<kineticModel>
    (
        cstrIter()(mesh, dict, specieName)
    );
}


// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //

bool kineticModel::read()
{
    return true;
}


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// ************************************************************************* //
