/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Namespace
    Foam::kineticModels

Group
    grpIcoRASTurbulence

Description
    Namespace for calculating overall mass transfer coefficient per cell

Class
    Foam::kineticModel

SourceFiles
    kineticModel.C

\*---------------------------------------------------------------------------*/

#ifndef kineticModel_H
#define kineticModel_H

#include "IOdictionary.H"
#include "typeInfo.H"
#include "volFields.H"
#include "dimensionedScalar.H"
#include "Pair.H"
#include "nearWallDist.H"
#include "autoPtr.H"
#include "runTimeSelectionTables.H"
#include "fvCFD.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                           Class kineticModel Declaration
\*---------------------------------------------------------------------------*/

class kineticModel
{

protected:

    // Protected data


private:

    // Private Member Functions

        //- Disallow default bitwise copy construct
        kineticModel(const kineticModel&);

        //- Disallow default bitwise assignment
        void operator=(const kineticModel&);


public:

    //- Runtime type information
    TypeName("kineticModel");


    // Declare run-time constructor selection table

        declareRunTimeSelectionTable
        (
            autoPtr,
            kineticModel,
            subModel,
            (
                const fvMesh& mesh,
                const dictionary& dict,
                const word& specieName
            ),
            (mesh, dict, specieName)
        );


    // Constructors

        //- Construct from components
        kineticModel
        (
            const word& type,
            const fvMesh& mesh,
            const dictionary& dict,
            const word& specieName
        );


    // Selectors

        //- Return a reference to the selected RAS model
        static autoPtr<kineticModel> New
        (
            const fvMesh& mesh,
            const dictionary& dict,
            const word& specieName
        );


    //- Destructor
    virtual ~kineticModel()
    {}


    // Member Functions

        //- Return the mass transfer area per cell 
        virtual tmp<volScalarField> massTransferCoeff() = 0;

        //- Read dictionary
        virtual bool read();
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
